@@ -1,7 +1,6 @@
 """Base class for all data checks."""
 from abc import ABC, abstractmethod
 
-from evalml.data_checks.data_check_message_type import DataCheckMessageType
 from evalml.utils import classproperty
 
 
@@ -28,10 +27,3 @@ class DataCheck(ABC):
         Returns:
             dict (DataCheckMessage): Dictionary of DataCheckError and DataCheckWarning messages
         """
-
-    @staticmethod
-    def _add_message(message, results):
-        if message.message_type == DataCheckMessageType.ERROR:
-            results["errors"].append(message.to_dict())
-        elif message.message_type == DataCheckMessageType.WARNING:
-            results["warnings"].append(message.to_dict())
