@@ -115,14 +115,16 @@ class XGBoostRegressor(Estimator):
         X: pd.DataFrame,
         y: Optional[pd.Series] = None,
         coverage: List[float] = None,
+        predictions: pd.Series = None,
     ) -> Dict[str, pd.Series]:
-        """Find the prediction intervals using the fitted ProphetRegressor.
+        """Find the prediction intervals using the fitted XGBoostRegressor.
 
         Args:
             X (pd.DataFrame): Data of shape [n_samples, n_features].
             y (pd.Series): Target data. Ignored.
             coverage (List[float]): A list of floats between the values 0 and 1 that the upper and lower bounds of the
                 prediction interval should be calculated for.
+            predictions (pd.Series): Optional list of predictions to use. If None, will generate predictions using `X`.
 
         Returns:
             dict: Prediction intervals, keys are in the format {coverage}_lower or {coverage}_upper.
@@ -132,6 +134,7 @@ class XGBoostRegressor(Estimator):
             X=X,
             y=y,
             coverage=coverage,
+            predictions=predictions,
         )
         return prediction_interval_result
 
