@@ -19,13 +19,15 @@ class DropRowsTransformer(Transformer):
 
     def __init__(self, indices_to_drop=None, random_seed=0):
         if indices_to_drop is not None and len(set(indices_to_drop)) != len(
-            indices_to_drop
+            indices_to_drop,
         ):
             raise ValueError("All input indices must be unique.")
         self.indices_to_drop = indices_to_drop
         parameters = {"indices_to_drop": self.indices_to_drop}
         super().__init__(
-            parameters=parameters, component_obj=None, random_seed=random_seed
+            parameters=parameters,
+            component_obj=None,
+            random_seed=random_seed,
         )
 
     def fit(self, X, y=None):
@@ -54,14 +56,14 @@ class DropRowsTransformer(Transformer):
             if len(missing_X_indices):
                 raise ValueError(
                     "Indices [{}] do not exist in input features".format(
-                        list(missing_X_indices)
-                    )
+                        list(missing_X_indices),
+                    ),
                 )
             elif y_t is not None and len(missing_y_indices):
                 raise ValueError(
                     "Indices [{}] do not exist in input target".format(
-                        list(missing_y_indices)
-                    )
+                        list(missing_y_indices),
+                    ),
                 )
         return self
 
@@ -79,11 +81,11 @@ class DropRowsTransformer(Transformer):
         y_t = infer_feature_types(y) if y is not None else None
         if self.indices_to_drop is None or len(self.indices_to_drop) == 0:
             return X_t, y_t
+        schema = X_t.ww.schema
 
         X_t = X_t.drop(self.indices_to_drop, axis=0)
-        X_t.ww.init()
+        X_t.ww.init(schema=schema)
 
         if y_t is not None:
-            y_t = y_t.drop(self.indices_to_drop)
-            y_t.ww.init()
+            y_t = y_t.ww.drop(self.indices_to_drop)
         return X_t, y_t
