@@ -397,7 +397,7 @@ def generate_component_code(element):
 
     Examples:
         >>> from evalml.pipelines.components.estimators.regressors.decision_tree_regressor import DecisionTreeRegressor
-        >>> assert generate_component_code(DecisionTreeRegressor()) == "from evalml.pipelines.components.estimators.regressors.decision_tree_regressor import DecisionTreeRegressor\n\ndecisionTreeRegressor = DecisionTreeRegressor(**{'criterion': 'mse', 'max_features': 'auto', 'max_depth': 6, 'min_samples_split': 2, 'min_weight_fraction_leaf': 0.0})"
+        >>> assert generate_component_code(DecisionTreeRegressor()) == "from evalml.pipelines.components.estimators.regressors.decision_tree_regressor import DecisionTreeRegressor\n\ndecisionTreeRegressor = DecisionTreeRegressor(**{'criterion': 'squared_error', 'max_features': 'auto', 'max_depth': 6, 'min_samples_split': 2, 'min_weight_fraction_leaf': 0.0})"
         ...
         >>> from evalml.pipelines.components.transformers.imputers.simple_imputer import SimpleImputer
         >>> assert generate_component_code(SimpleImputer()) == "from evalml.pipelines.components.transformers.imputers.simple_imputer import SimpleImputer\n\nsimpleImputer = SimpleImputer(**{'impute_strategy': 'most_frequent', 'fill_value': None})"
@@ -471,3 +471,61 @@ def make_balancing_dictionary(y, sampling_ratio):
             # this class is already larger than the ratio, don't change
             class_dic[index] = value_counts[index]
     return class_dic
+
+
+def handle_float_categories_for_catboost(X):
+    """Updates input data to be compatible with CatBoost estimators.
+
+    CatBoost cannot handle data in X that is the Categorical Woodwork logical type with floating point categories.
+    This utility determines if the floating point categories can be converted to integers
+    without truncating any data, and if they can be, converts them to int64 categories.
+    Will not attempt to use values that are truly floating points.
+
+    Args:
+        X (pd.DataFrame): Input data to CatBoost that has Woodwork initialized
+
+    Returns:
+        DataFrame: Input data with exact same Woodwork typing info as the original but with any float categories
+            converted to be int64 when possible.
+
+    Raises:
+        ValueError: if the numeric categories are actual floats that cannot be converted to integers
+            without truncating data
+    """
+    original_schema = X.ww.schema
+    original_dtypes = X.dtypes
+
+    # Determine which categorical columns have float categories, which CatBoost would error on
+    categorical_columns = X.ww.select("category", return_schema=True).columns.keys()
+    cols_with_float_categories = [
+        col
+        for col in categorical_columns
+        if original_dtypes[col].categories.dtype == "float64"
+    ]
+
+    if not cols_with_float_categories:
+        return X
+
+    # determine which columns are really integers vs are actually floats
+    new_dtypes = {}
+    for col in cols_with_float_categories:
+        col_categories = original_dtypes[col].categories
+        floats_are_really_ints = (col_categories % 1 == 0).all()
+        if floats_are_really_ints:
+            # We can use non nullable int64 here because there will not be any nans at this point
+            new_categories = col_categories.astype("int64")
+            new_dtypes[col] = pd.CategoricalDtype(
+                categories=new_categories,
+                ordered=original_dtypes[col].ordered,
+            )
+        else:
+            # CatBoost explanation as to why they don't support float categories: https://catboost.ai/en/docs/concepts/faq#floating-point-values
+            # CatBoost bug keeping us from converting to string: https://github.com/catboost/catboost/issues/1965
+            # Pandas bug keeping us from converting `.astype("string").astype("object")`: https://github.com/pandas-dev/pandas/issues/51074
+            raise ValueError(
+                f"Invalid category found in {col}. CatBoost does not support floats as categories.",
+            )
+
+    X_t = X.astype(new_dtypes)
+    X_t.ww.init(schema=original_schema)
+    return X_t
