@@ -4,6 +4,8 @@ from unittest.mock import patch
 import numpy as np
 import pandas as pd
 import pytest
+from sktime.forecasting.arima import AutoARIMA as SKArima
+from sktime.forecasting.base import ForecastingHorizon
 
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components import ARIMARegressor
@@ -472,3 +474,98 @@ def test_arima_regressor_can_forecast_arbitrary_dates(use_covariates, ts_data):
     assert (
         arima.predict(X_test).tail(5).tolist() == arima.predict(X_test_last_5).tolist()
     )
+
+
+def test_arima_regressor_nullable_handling():
+    X = pd.DataFrame()
+    X["nums"] = pd.Series([i for i in range(100)], dtype="Int64")
+    X.index = pd.date_range("1/1/21", periods=100)
+    X.ww.init(logical_types={"nums": "IntegerNullable"})
+
+    y = pd.Series([i for i in range(100)], dtype="Int64")
+    y.index = pd.date_range("1/1/21", periods=100)
+
+    X_train = X.ww.iloc[:80, :]
+    X_test = X.ww.iloc[80:, :]
+
+    y_train = y[:80]
+
+    arima_params = {
+        "trend": None,
+        "start_p": 2,
+        "d": 0,
+        "start_q": 2,
+        "max_p": 5,
+        "max_d": 2,
+        "max_q": 5,
+        "seasonal": True,
+        "maxiter": 10,
+        "n_jobs": -1,
+    }
+
+    evalml_arima = ARIMARegressor(**arima_params)
+    evalml_arima.fit(X_train, y_train)
+    preds = evalml_arima.predict(X=X_test)
+    assert not preds.isnull().any().any()
+
+
+@pytest.mark.parametrize(
+    "nullable_ltype",
+    ["IntegerNullable", "AgeNullable"],
+)
+@pytest.mark.parametrize(
+    "handle_incompatibility",
+    [
+        True,
+        pytest.param(
+            False,
+            marks=pytest.mark.xfail(strict=True, raises=ValueError),
+        ),
+    ],
+)
+def test_arima_nullable_type_incompatibility(
+    handle_incompatibility,
+    nullable_ltype,
+):
+    """Testing that the nullable type incompatibility that caused us to add handling for ARIMARegressor
+    is still present in sktime's AutoARIMA component. If this test is causing the test suite to fail
+    because the code below no longer raises the expected ValueError, we should confirm that the nullable
+    types now work for our use case and remove the nullable type handling logic from ARIMARegressor.
+    """
+    X = pd.DataFrame()
+    X["nums"] = pd.Series([i for i in range(100)], dtype="Int64")
+    X.index = pd.date_range("1/1/21", periods=100)
+    X.ww.init(logical_types={"nums": nullable_ltype})
+
+    y = pd.Series([i for i in range(100)], dtype="Int64")
+    y.index = pd.date_range("1/1/21", periods=100)
+
+    arima_params = {
+        "trend": None,
+        "start_p": 2,
+        "d": 0,
+        "start_q": 2,
+        "max_p": 5,
+        "max_d": 2,
+        "max_q": 5,
+        "seasonal": True,
+        "maxiter": 10,
+        "n_jobs": -1,
+    }
+
+    if handle_incompatibility:
+        evalml_arima = ARIMARegressor(**arima_params)
+        X, y = evalml_arima._handle_nullable_types(X, y)
+
+    X_train = X.ww.iloc[:80, :]
+    X_test = X.ww.iloc[80:, :]
+    y_train = y[:80]
+
+    # SKTime's AutoARIMA regressor cannot handle IntegerNullable type
+    sk_arima = SKArima(**arima_params)
+    fh_ = ForecastingHorizon(
+        [i + 1 for i in range(len(X_test))],
+        is_relative=True,
+    )
+    sk_arima.fit(y=y_train, X=X_train)
+    sk_arima.predict(fh=fh_, X=X_test)
