@@ -1,5 +1,7 @@
 import warnings
 
+import pandas as pd
+
 from evalml.pipelines.components import CatBoostRegressor
 from evalml.utils import SEED_BOUNDS
 
@@ -35,3 +37,14 @@ def test_catboost_regressor_init_thread_count():
         CatBoostRegressor(thread_count=2)
     assert len(w) == 1
     assert "Parameter 'thread_count' will be ignored. " in str(w[-1].message)
+
+
+def test_catboost_regressor_double_categories_in_X(categorical_floats_df):
+    X = categorical_floats_df
+    y = pd.Series([1, 2, 3, 4, 5] * 20)
+
+    clf = CatBoostRegressor()
+    fitted = clf.fit(X, y)
+    assert isinstance(fitted, CatBoostRegressor)
+    predictions = clf.predict(X)
+    assert isinstance(predictions, pd.Series)
