@@ -8,6 +8,7 @@ import cloudpickle
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
 from skopt.space import Categorical
 
 from evalml.exceptions import ComponentNotYetFittedError, MethodPropertyNotFoundError
@@ -92,6 +93,9 @@ from evalml.pipelines.components.utils import (
     generate_component_code,
 )
 from evalml.problem_types import ProblemTypes
+from evalml.tests.conftest import (
+    CustomComponent,
+)
 
 
 @pytest.fixture(scope="module")
@@ -1804,3 +1808,161 @@ def test_component_parameters_supported_by_list_API(component_class):
         assert not component_class._supported_by_list_API
     else:
         assert component_class._supported_by_list_API
+
+
+@pytest.mark.parametrize(
+    "nullable_y_ltype",
+    ["BooleanNullable", "IntegerNullable", "AgeNullable"],
+)
+@pytest.mark.parametrize("X_bool_null_incompatible", [True, False])
+@pytest.mark.parametrize("X_int_null_incompatible", [True, False])
+@pytest.mark.parametrize("y_bool_null_incompatible", [True, False])
+@pytest.mark.parametrize("y_int_null_incompatible", [True, False])
+def test_handle_nullable_types(
+    split_nullable_logical_types_by_compatibility,
+    nullable_type_test_data,
+    nullable_type_target,
+    X_bool_null_incompatible,
+    X_int_null_incompatible,
+    y_bool_null_incompatible,
+    y_int_null_incompatible,
+    nullable_y_ltype,
+):
+    """Tests all 4^2 combinations of X and y nullable type incompatibilities with
+    int nullable or boolean nullable with all the different options for y's logical type.
+    """
+    y = nullable_type_target(ltype=nullable_y_ltype, has_nans=True)
+    X = nullable_type_test_data(has_nans=True)
+
+    # Recreate the properties needed to specify incompatibilities
+    integer_nullable_incompatibilities = []
+    if X_int_null_incompatible:
+        integer_nullable_incompatibilities.append("X")
+    if y_int_null_incompatible:
+        integer_nullable_incompatibilities.append("y")
+
+    boolean_nullable_incompatibilities = []
+    if y_bool_null_incompatible:
+        boolean_nullable_incompatibilities.append("y")
+    if X_bool_null_incompatible:
+        boolean_nullable_incompatibilities.append("X")
+
+    cmp = CustomComponent(
+        integer_nullable_incompatibilities,
+        boolean_nullable_incompatibilities,
+    )
+    X_d, y_d = cmp._handle_nullable_types(X, y)
+
+    # Confirm that the incompatibilities specified above actually remove any incompatible
+    # logical types and that compatible logical types remain
+    (
+        X_compatible_ltypes,
+        X_incompatible_ltypes,
+    ) = split_nullable_logical_types_by_compatibility(
+        X_int_null_incompatible,
+        X_bool_null_incompatible,
+    )
+    (
+        y_compatible_ltypes,
+        y_incompatible_ltypes,
+    ) = split_nullable_logical_types_by_compatibility(
+        y_int_null_incompatible,
+        y_bool_null_incompatible,
+    )
+
+    assert len(X_d.ww.select(X_incompatible_ltypes).columns) == 0
+    assert len(X_d.ww.select(X_compatible_ltypes).columns) == len(
+        X.ww.select(X_compatible_ltypes).columns,
+    )
+
+    if nullable_y_ltype in {str(ltype) for ltype in y_compatible_ltypes}:
+        assert isinstance(
+            y_d.ww.logical_type,
+            tuple(y_compatible_ltypes),
+        )
+    else:
+        assert not isinstance(
+            y_d.ww.logical_type,
+            tuple(y_incompatible_ltypes),
+        )
+
+
+@pytest.mark.parametrize(
+    "component_class",
+    [
+        comp
+        for comp in all_components()
+        if not (
+            comp._integer_nullable_incompatibilities
+            or comp._boolean_nullable_incompatibilities
+        )
+    ],
+)
+@pytest.mark.parametrize(
+    "nullable_y_ltype",
+    ["BooleanNullable", "IntegerNullable", "AgeNullable"],
+)
+def test_components_support_nullable_types(
+    nullable_y_ltype,
+    component_class,
+    nullable_type_test_data,
+    nullable_type_target,
+    ts_data,
+    helper_functions,
+):
+    """Confirm that components without any nullable type incompatibilities can actually
+    use all the nullable types in X and y in fit and predict/transform. If a new
+    component is added that has nullable type incompatibilities, this should fail."""
+    cannot_handle_boolean_target = [CatBoostRegressor]
+
+    if component_class == TimeSeriesBaselineEstimator:
+        pytest.skip(
+            "Time Series Baseline Estimator can only be used within a Pipeline.",
+        )
+
+    elif (
+        component_class in cannot_handle_boolean_target
+        and nullable_y_ltype == "BooleanNullable"
+    ):
+        pytest.skip(f"Cannot pass boolean y into {component_class}.")
+
+    # Some components require special handling to fit and predict/transform
+    requires_time_index = [
+        ProphetRegressor,
+        TimeSeriesFeaturizer,
+        TimeSeriesRegularizer,
+        PolynomialDecomposer,
+        STLDecomposer,
+    ]
+    requires_all_numeric = [PCA, LinearDiscriminantAnalysis]
+
+    component = helper_functions.safe_init_component_with_njobs_1(component_class)
+    if component_class in requires_time_index:
+        component = component_class(time_index="date")
+
+        X, _, y = ts_data()
+        bool_col = ww.init_series(
+            pd.Series([True, False] * 20, index=y.index),
+            "BooleanNullable",
+        )
+
+        if nullable_y_ltype == "BooleanNullable":
+            y = bool_col
+
+        # Add nullable types
+        X.ww.set_types(logical_types={"feature": "IntegerNullable"})
+        X.ww["bool col"] = bool_col
+    else:
+        y = nullable_type_target(ltype=nullable_y_ltype, has_nans=False)
+        X = nullable_type_test_data(has_nans=False)
+
+        if component_class in requires_all_numeric:
+            X = X.ww.select(["numeric"])
+        else:
+            X = X.ww.select(["numeric", "Boolean", "BooleanNullable"])
+
+    component.fit(X, y)
+    if issubclass(component_class, Estimator):
+        component.predict(X)
+    else:
+        component.transform(X, y)
