@@ -121,29 +121,32 @@ def test_cols():
         {
             "col_1": [1, 2, 1, 1, 2] * 2,
             "col_2": ["2", "1", "1", "1", "1"] * 2,
-            "col_3": ["a", "a", "a", "a", "a"] * 2,
+            "col_3": ["a", "a", "a", "a", "b"] * 2,
         },
     )
-    X_expected = X.astype({"col_1": "int64", "col_2": "category", "col_3": "category"})
+    X_expected = X.astype({"col_1": "int64", "col_2": "int64", "col_3": "category"})
     y = pd.Series([0, 1, 1, 1, 0] * 2)
     encoder = TargetEncoder(cols=[])
     encoder.fit(X, y)
     X_t = encoder.transform(X)
     assert_frame_equal(X_expected, X_t)
 
-    encoder = TargetEncoder(cols=["col_2"])
+    encoder = TargetEncoder(cols=["col_3"])
     encoder.fit(X, y)
     X_t = encoder.transform(X)
     X_expected = pd.DataFrame(
         {
             "col_1": pd.Series([1, 2, 1, 1, 2] * 2, dtype="int64"),
-            "col_2": [0.161365, 0.749863, 0.749863, 0.749863, 0.749863] * 2,
-            "col_3": pd.Series(["a", "a", "a", "a", "a"] * 2, dtype="category"),
+            "col_2": [2, 1, 1, 1, 1] * 2,
+            "col_3": pd.Series(
+                [0.749863, 0.749863, 0.749863, 0.749863, 0.161365] * 2,
+                dtype="float64",
+            ),
         },
     )
     assert_frame_equal(X_expected, X_t, check_less_precise=True)
 
-    encoder = TargetEncoder(cols=["col_2", "col_3"])
+    encoder = TargetEncoder(cols=["col_3"])
     encoder.fit(X, y)
     X_t = encoder.transform(X)
     encoder2 = TargetEncoder()
