@@ -1,5 +1,7 @@
+import os
 from unittest.mock import patch
 
+import black
 import numpy as np
 import pandas as pd
 import pytest
@@ -45,6 +47,7 @@ from evalml.pipelines.utils import (
     _get_preprocessing_components,
     _make_pipeline_from_multiple_graphs,
     generate_pipeline_code,
+    generate_pipeline_example,
     get_estimators,
     is_classification,
     is_regression,
@@ -653,7 +656,7 @@ def test_generate_code_pipeline_errors():
         generate_pipeline_code([Imputer(), LogisticRegressionClassifier()])
 
 
-def test_generate_code_pipeline_json_with_objects():
+def test_generate_code_pipeline_json_with_objects(get_black_config):
     class CustomEstimator(Estimator):
         name = "My Custom Estimator"
         hyperparameter_ranges = {}
@@ -676,12 +679,12 @@ def test_generate_code_pipeline_json_with_objects():
         parameters={"My Custom Estimator": {"numpy_arg": np.array([0])}},
     )
     generated_pipeline_code = generate_pipeline_code(pipeline)
-    assert (
-        generated_pipeline_code
-        == "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
+    assert generated_pipeline_code == black.format_str(
+        "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'My Custom Estimator': [CustomEstimator, 'Imputer.x', 'y']}, "
         "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
-        "'My Custom Estimator':{'random_arg': False, 'numpy_arg': array([0])}}, custom_name='Mock Binary Pipeline with Transformer', random_seed=0)"
+        "'My Custom Estimator':{'random_arg': False, 'numpy_arg': array([0])}}, custom_name='Mock Binary Pipeline with Transformer', random_seed=0)",
+        mode=black.Mode(**get_black_config),
     )
 
     pipeline = BinaryClassificationPipeline(
@@ -690,26 +693,28 @@ def test_generate_code_pipeline_json_with_objects():
         parameters={"My Custom Estimator": {"random_arg": Imputer()}},
     )
     generated_pipeline_code = generate_pipeline_code(pipeline)
-    assert (
-        generated_pipeline_code
-        == "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
+    assert generated_pipeline_code == black.format_str(
+        "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'My Custom Estimator': [CustomEstimator, 'Imputer.x', 'y']}, "
         "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
         "'My Custom Estimator':{'random_arg': Imputer(categorical_impute_strategy='most_frequent', numeric_impute_strategy='mean', boolean_impute_strategy='most_frequent', categorical_fill_value=None, numeric_fill_value=None, boolean_fill_value=None), 'numpy_arg': []}}, "
-        "custom_name='Mock Binary Pipeline with Transformer', random_seed=0)"
+        "custom_name='Mock Binary Pipeline with Transformer', random_seed=0)",
+        mode=black.Mode(**get_black_config),
     )
 
 
-def test_generate_code_pipeline():
+def test_generate_code_pipeline(get_black_config):
     binary_pipeline = BinaryClassificationPipeline(
         ["Imputer", "Random Forest Classifier"],
     )
-    expected_code = (
+    expected_code = black.format_str(
         "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'Random Forest Classifier': ['Random Forest Classifier', 'Imputer.x', 'y']}, "
         "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
-        "'Random Forest Classifier':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}}, random_seed=0)"
+        "'Random Forest Classifier':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}}, random_seed=0)",
+        mode=black.Mode(**get_black_config),
     )
+
     pipeline = generate_pipeline_code(binary_pipeline)
     assert expected_code == pipeline
 
@@ -717,33 +722,36 @@ def test_generate_code_pipeline():
         ["Imputer", "Random Forest Regressor"],
         custom_name="Mock Regression Pipeline",
     )
-    expected_code = (
+    expected_code = black.format_str(
         "from evalml.pipelines.regression_pipeline import RegressionPipeline\n"
         "pipeline = RegressionPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'Random Forest Regressor': ['Random Forest Regressor', 'Imputer.x', 'y']}, parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
-        "'Random Forest Regressor':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}}, custom_name='Mock Regression Pipeline', random_seed=0)"
+        "'Random Forest Regressor':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}}, custom_name='Mock Regression Pipeline', random_seed=0)",
+        mode=black.Mode(**get_black_config),
     )
     pipeline = generate_pipeline_code(regression_pipeline)
     assert pipeline == expected_code
 
     regression_pipeline_with_params = RegressionPipeline(
-        ["Imputer", "Random Forest Regressor"],
+        ["DFS Transformer", "Imputer", "Random Forest Regressor"],
         custom_name="Mock Regression Pipeline",
         parameters={
+            "DFS Transformer": {"features": None},
             "Imputer": {"numeric_impute_strategy": "most_frequent"},
             "Random Forest Regressor": {"n_estimators": 50},
         },
     )
-    expected_code_params = (
+    expected_code_params = black.format_str(
         "from evalml.pipelines.regression_pipeline import RegressionPipeline\n"
-        "pipeline = RegressionPipeline(component_graph={'Imputer': ['Imputer', 'X', 'y'], 'Random Forest Regressor': ['Random Forest Regressor', 'Imputer.x', 'y']}, "
-        "parameters={'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'most_frequent', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
-        "'Random Forest Regressor':{'n_estimators': 50, 'max_depth': 6, 'n_jobs': -1}}, custom_name='Mock Regression Pipeline', random_seed=0)"
+        "pipeline = RegressionPipeline(component_graph={'DFS Transformer': ['DFS Transformer', 'X', 'y'],'Imputer': ['Imputer', 'DFS Transformer.x', 'y'], 'Random Forest Regressor': ['Random Forest Regressor', 'Imputer.x', 'y']}, "
+        "parameters={'DFS Transformer':{}, 'Imputer':{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'most_frequent', 'boolean_impute_strategy': 'most_frequent', 'categorical_fill_value': None, 'numeric_fill_value': None, 'boolean_fill_value': None}, "
+        "'Random Forest Regressor':{'n_estimators': 50, 'max_depth': 6, 'n_jobs': -1}}, custom_name='Mock Regression Pipeline', random_seed=0)",
+        mode=black.Mode(**get_black_config),
     )
     pipeline = generate_pipeline_code(regression_pipeline_with_params)
     assert pipeline == expected_code_params
 
 
-def test_generate_code_nonlinear_pipeline():
+def test_generate_code_nonlinear_pipeline(get_black_config):
     custom_name = "Non Linear Binary Pipeline"
     component_graph = {
         "Imputer": ["Imputer", "X", "y"],
@@ -762,7 +770,7 @@ def test_generate_code_nonlinear_pipeline():
         component_graph=component_graph,
         custom_name=custom_name,
     )
-    expected = (
+    expected = black.format_str(
         "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline("
         "component_graph={'Imputer': ['Imputer', 'X', 'y'], "
@@ -777,13 +785,14 @@ def test_generate_code_nonlinear_pipeline():
         "'Random Forest':{'n_estimators': 100, 'max_depth': 6, 'n_jobs': -1}, "
         "'Elastic Net':{'penalty': 'elasticnet', 'C': 1.0, 'l1_ratio': 0.15, 'n_jobs': -1, 'multi_class': 'auto', 'solver': 'saga'}, "
         "'Logistic Regression Classifier':{'penalty': 'l2', 'C': 1.0, 'n_jobs': -1, 'multi_class': 'auto', 'solver': 'lbfgs'}}, "
-        "custom_name='Non Linear Binary Pipeline', random_seed=0)"
+        "custom_name='Non Linear Binary Pipeline', random_seed=0)",
+        mode=black.Mode(**get_black_config),
     )
     pipeline_code = generate_pipeline_code(pipeline)
     assert pipeline_code == expected
 
 
-def test_generate_code_pipeline_with_custom_components():
+def test_generate_code_pipeline_with_custom_components(get_black_config):
     class CustomTransformer(Transformer):
         name = "My Custom Transformer"
         hyperparameter_ranges = {}
@@ -818,15 +827,185 @@ def test_generate_code_pipeline_with_custom_components():
     mock_pipeline_with_custom_components = BinaryClassificationPipeline(
         [CustomTransformer, CustomEstimator],
     )
-    expected_code = (
+    expected_code = black.format_str(
         "from evalml.pipelines.binary_classification_pipeline import BinaryClassificationPipeline\n"
         "pipeline = BinaryClassificationPipeline(component_graph={'My Custom Transformer': [CustomTransformer, 'X', 'y'], 'My Custom Estimator': [CustomEstimator, 'My Custom Transformer.x', 'y']}, "
-        "parameters={'My Custom Estimator':{'random_arg': False}}, random_seed=0)"
+        "parameters={'My Custom Estimator':{'random_arg': False}}, random_seed=0)",
+        mode=black.Mode(**get_black_config),
     )
     pipeline = generate_pipeline_code(mock_pipeline_with_custom_components)
     assert pipeline == expected_code
 
 
+@pytest.mark.parametrize(
+    "automl_type",
+    [
+        ProblemTypes.BINARY,
+        ProblemTypes.MULTICLASS,
+        ProblemTypes.REGRESSION,
+        ProblemTypes.TIME_SERIES_REGRESSION,
+        ProblemTypes.TIME_SERIES_MULTICLASS,
+        ProblemTypes.TIME_SERIES_BINARY,
+    ],
+)
+def test_generate_pipeline_example(
+    automl_type,
+    tmpdir,
+    AutoMLTestEnv,
+    X_y_binary,
+    X_y_multi,
+    X_y_regression,
+    ts_data,
+    is_using_windows,
+):
+    if is_using_windows:
+        pytest.xfail(
+            "Pipeline code generation is not expected to work on Windows machines",
+        )
+    if automl_type == ProblemTypes.BINARY:
+        X, y = X_y_binary
+    elif automl_type == ProblemTypes.MULTICLASS:
+        X, y = X_y_multi
+    elif automl_type == ProblemTypes.REGRESSION:
+        X, y = X_y_regression
+    elif is_time_series(automl_type):
+        X, _, y = ts_data(problem_type=automl_type)
+
+    problem_configuration = (
+        {
+            "time_index": "date",
+            "gap": 1,
+            "max_delay": 1,
+            "forecast_horizon": 3,
+        }
+        if is_time_series(automl_type)
+        else None
+    )
+
+    import featuretools as ft
+
+    from evalml import AutoMLSearch
+    from evalml.preprocessing import split_data
+
+    X_train, X_test, y_train, y_test = split_data(
+        X,
+        y,
+        problem_type=automl_type,
+        test_size=0.2,
+    )
+
+    X_train = pd.DataFrame(X_train)
+    X_train.columns = X_train.columns.astype(str)
+    es = ft.EntitySet()
+    es = es.add_dataframe(
+        dataframe_name="X",
+        dataframe=X_train,
+        index="index",
+        make_index=False,
+    )
+    X_train_t, features = ft.dfs(
+        entityset=es,
+        target_dataframe_name="X",
+        trans_primitives=["absolute"],
+        return_types="all",
+    )
+    features_path = os.path.join(str(tmpdir), "features.json")
+    ft.save_features(features, features_path)
+
+    aml = AutoMLSearch(
+        X_train=X_train_t,
+        y_train=y_train,
+        problem_type=automl_type,
+        optimize_thresholds=False,
+        max_iterations=5,
+        problem_configuration=problem_configuration,
+        features=features,
+    )
+    env = AutoMLTestEnv(automl_type)
+    with env.test_context(score_return_value={aml.objective.name: 1.0}):
+        aml.search()
+
+    pipeline = aml.get_pipeline(2)
+
+    y_train.index = X_train_t.index
+    y_test.index = X_test.index
+    X_train_t.ww["target"] = y_train
+    X_test.ww["target"] = y_test.reindex(X_test.index)
+
+    train_path = os.path.join(str(tmpdir), "train")
+    holdout_path = os.path.join(str(tmpdir), "holdout")
+
+    X_train_t.ww.to_disk(train_path)
+    X_test.ww.to_disk(holdout_path)
+    output_path = os.path.join(str(tmpdir), "example.py")
+
+    # extra features provided to example
+    with pytest.raises(
+        ValueError,
+        match="Provided features in `features_path` do not match pipeline features. There is a different amount of features in the loaded features.",
+    ):
+        _, false_features = ft.dfs(
+            entityset=es,
+            target_dataframe_name="X",
+            trans_primitives=["absolute", "is_null"],
+            return_types="all",
+        )
+        false_features_path = os.path.join(str(tmpdir), "false_features.json")
+        ft.save_features(false_features, false_features_path)
+        _ = generate_pipeline_example(
+            pipeline=pipeline,
+            path_to_train=train_path,
+            path_to_holdout=holdout_path,
+            path_to_features=false_features_path,
+            target="target",
+            output_file_path=output_path,
+        )
+
+    # different features provided to example
+    with pytest.raises(
+        ValueError,
+        match="Provided features in `features_path` do not match pipeline features.",
+    ):
+        _, false_features = ft.dfs(
+            entityset=es,
+            target_dataframe_name="X",
+            trans_primitives=["sine"],
+            return_types="all",
+        )
+        false_features_path = os.path.join(str(tmpdir), "false_features.json")
+        ft.save_features(false_features, false_features_path)
+        _ = generate_pipeline_example(
+            pipeline=pipeline,
+            path_to_train=train_path,
+            path_to_holdout=holdout_path,
+            path_to_features=false_features_path,
+            target="target",
+            output_file_path=output_path,
+        )
+
+    pipeline_example = generate_pipeline_example(
+        pipeline=pipeline,
+        path_to_train=train_path,
+        path_to_holdout=holdout_path,
+        path_to_features=features_path,
+        target="target",
+        output_file_path=output_path,
+    )
+    assert f'PATH_TO_TRAIN = "{train_path}"' in pipeline_example
+    assert f'PATH_TO_HOLDOUT = "{holdout_path}"' in pipeline_example
+    assert 'TARGET = "target"' in pipeline_example
+    assert 'column_mapping = ""' in pipeline_example
+    assert generate_pipeline_code(pipeline, features_path) in pipeline_example
+
+    if is_time_series(automl_type):
+        assert "predict(X_test, X_train=X_train, y_train=y_train)" in pipeline_example
+    else:
+        assert "predict(X_test)" in pipeline_example
+
+    exec(pipeline_example)
+    assert os.path.exists(output_path)
+
+
 def test_rows_of_interest_errors(X_y_binary):
     pipeline = BinaryClassificationPipeline(
         component_graph=["Logistic Regression Classifier"],
